# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .generation_info import GenerationInfo
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class GuidelinePropositionInspection(UniversalBaseModel):
    """
    Inspection data for guideline proposition.
    """

    total_duration: float = pydantic.Field()
    """
    Amount of time spent proposing guidelines
    """

    batches: typing.List[GenerationInfo] = pydantic.Field()
    """
    A list of `GenerationInfoDTO` describing the batches of generation executed
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
