# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import pydantic
from .usage_info import UsageInfo
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class GenerationInfo(UniversalBaseModel):
    """
    Information about a text generation.
    """

    schema_name: str = pydantic.Field()
    """
    The name of the schema used for the generation
    """

    model: str = pydantic.Field()
    """
    Id of the model used for the generation
    """

    duration: float = pydantic.Field()
    """
    Amount of time spent generating
    """

    usage: UsageInfo

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
