# This file was auto-generated by Fern from our API Definition.

import typing

ConnectionPropositionKindDto = typing.Union[
    typing.Literal[
        "connection_with_existing_guideline",
        "connection_with_another_evaluated_guideline",
    ],
    typing.Any,
]
